==> openshift-model-5.1.1-sources.jar: io/fabric8/openshift/api/model/StepInfoFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class StepInfoFluentImpl<A extends StepInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StepInfoFluent<A> {

    private Long durationMilliseconds;
    private String name;
    private String startTime;

    public StepInfoFluentImpl() {
    }

    public StepInfoFluentImpl(StepInfo instance) {
        this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
        this.withName(instance.getName()); 
        this.withStartTime(instance.getStartTime()); 
    }

    public Long getDurationMilliseconds() {
        return this.durationMilliseconds;
    }

    public A withDurationMilliseconds(Long durationMilliseconds) {
        this.durationMilliseconds=durationMilliseconds; return (A) this;
    }

    public Boolean hasDurationMilliseconds() {
        return this.durationMilliseconds != null;
    }

    public A withNewDurationMilliseconds(String arg1) {
        return (A)withDurationMilliseconds(new Long(arg1));
    }

    public A withNewDurationMilliseconds(long arg1) {
        return (A)withDurationMilliseconds(new Long(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public String getStartTime() {
        return this.startTime;
    }

    public A withStartTime(String startTime) {
        this.startTime=startTime; return (A) this;
    }

    public Boolean hasStartTime() {
        return this.startTime != null;
    }

    public A withNewStartTime(String arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(StringBuilder arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(StringBuffer arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StepInfoFluentImpl that = (StepInfoFluentImpl) o;
        if (durationMilliseconds != null ? !durationMilliseconds.equals(that.durationMilliseconds) :that.durationMilliseconds != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(durationMilliseconds,  name,  startTime,  super.hashCode());
    }

}

==> openshift-model-5.3.1-sources.jar: io/fabric8/openshift/api/model/StepInfoFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class StepInfoFluentImpl<A extends StepInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StepInfoFluent<A> {

    private Long durationMilliseconds;
    private String name;
    private String startTime;

    public StepInfoFluentImpl() {
    }

    public StepInfoFluentImpl(StepInfo instance) {
        this.withDurationMilliseconds(instance.getDurationMilliseconds()); 
        this.withName(instance.getName()); 
        this.withStartTime(instance.getStartTime()); 
    }

    public Long getDurationMilliseconds() {
        return this.durationMilliseconds;
    }

    public A withDurationMilliseconds(Long durationMilliseconds) {
        this.durationMilliseconds=durationMilliseconds; return (A) this;
    }

    public Boolean hasDurationMilliseconds() {
        return this.durationMilliseconds != null;
    }

    public A withNewDurationMilliseconds(long arg1) {
        return (A)withDurationMilliseconds(new Long(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public String getStartTime() {
        return this.startTime;
    }

    public A withStartTime(String startTime) {
        this.startTime=startTime; return (A) this;
    }

    public Boolean hasStartTime() {
        return this.startTime != null;
    }

    public A withNewStartTime(StringBuilder arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(int[] arg1,int arg2,int arg3) {
        return (A)withStartTime(new String(arg1, arg2, arg3));
    }

    public A withNewStartTime(char[] arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(StringBuffer arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(byte[] arg1,int arg2) {
        return (A)withStartTime(new String(arg1, arg2));
    }

    public A withNewStartTime(byte[] arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public A withNewStartTime(char[] arg1,int arg2,int arg3) {
        return (A)withStartTime(new String(arg1, arg2, arg3));
    }

    public A withNewStartTime(byte[] arg1,int arg2,int arg3) {
        return (A)withStartTime(new String(arg1, arg2, arg3));
    }

    public A withNewStartTime(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withStartTime(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewStartTime(String arg1) {
        return (A)withStartTime(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StepInfoFluentImpl that = (StepInfoFluentImpl) o;
        if (durationMilliseconds != null ? !durationMilliseconds.equals(that.durationMilliseconds) :that.durationMilliseconds != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(durationMilliseconds,  name,  startTime,  super.hashCode());
    }

}
